@@ -16,6 +16,7 @@ mod nullable;
 mod parameter_collection;
 mod preallocated;
 mod prepared;
+mod result_set_metadata;
 mod statement_connection;
 
 pub mod buffers;
@@ -36,6 +37,7 @@ pub use self::{
     parameter_collection::ParameterCollection,
     preallocated::Preallocated,
     prepared::Prepared,
+    result_set_metadata::ResultSetMetadata,
     statement_connection::StatementConnection,
 };
 // Reexports
